Modules
Macros
Structs
- AdtConflict
- AdtDecl
- A type declaration for an algebraic data type.
- Collect
Adts Error - Engine
- Engine
Options - Enum
Patch - Export
- GasCosts
- GasMeter
- Heap
- Json
Options - Options for handling enum JSON encodings.
- Module
- Parser
- Parser
Err - Parser
Limits - Pointer
- Program
- Scheme
- Type
- Type
System - Value
Display Options
Enums
- Builtin
Type Id - Engine
Error - Prelude
Mode - Token
- A Token represents a lexical token in the Rex programming language. It includes the values of literals, identifiers, and comments.
- Type
Error - Type
Kind - Value
Constants
Traits
- Async
Handler - From
Pointer - Handler
- Into
Pointer - RexAdt
- Shared ADT registration surface for derived and manually implemented Rust types.
- RexDefault
- RexType
Functions
- closure_
debug - closure_
eq - collect_
adts_ error_ to_ engine - Convert ADT collection conflicts into an embedder-facing
EngineError. - collect_
adts_ in_ types - Collect all user-defined ADT constructors referenced by the provided types.
- eval
- intern
- json_
to_ rex - Convert a JSON
Valueinto a typed Rex runtime value (Pointer) allocated onheap. - pointer_
display - pointer_
display_ with - rex_
to_ json - Convert a typed Rex runtime value (
Pointer) to a JSONValue. - sym
- value_
debug - value_
eq